nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Inten

Struct Inten 

#[repr(transparent)]
pub struct Inten(pub u32);
USB interrupt enable register

Tuple Fields

0: u32

Implementations

Source

impl Inten

pub const fn ep_int_en(&self) -> u16

If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line.

pub const fn set_ep_int_en(&mut self, val: u16)

If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line.

pub const fn frame_int_en(&self) -> bool

If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line.

pub const fn set_frame_int_en(&mut self, val: bool)

If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line.

pub const fn dev_int_en(&self) -> bool

If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line.

pub const fn set_dev_int_en(&mut self, val: bool)

If this bit is set and the corresponding USB interrupt status bit is set, a HW interrupt is generated on the interrupt line.